@@ -9,14 +9,14 @@
 
 
 // norm = maximum absolute column sum
-static inline float norm_macs(const len_t m, const len_t n, const float *const restrict x)
+static inline float norm_macs(const float_len_t m, const float_len_t n, const float *const restrict x)
 {
   float norm = 0.0f;
   
-  for (len_t j=0; j<n; j++)
+  for (float_len_t j=0; j<n; j++)
   {
     float tmp = 0.0f;
-    for (len_t i=0; i<m; i++)
+    for (float_len_t i=0; i<m; i++)
       tmp += fabsf(x[i + m*j]);
     
     if (tmp > norm)
@@ -27,7 +27,7 @@ static inline float norm_macs(const len_t m, const len_t n, const float *const r
 }
 
 // maximum absolute row sum
-static inline float norm_mars(const len_t m, const len_t n, const float *const restrict x)
+static inline float norm_mars(const float_len_t m, const float_len_t n, const float *const restrict x)
 {
   float norm = 0.0f;
   float *tmp = malloc(m*sizeof(*tmp));
@@ -35,13 +35,13 @@ static inline float norm_mars(const len_t m, const len_t n, const float *const r
   
   memset(tmp, 0.0f, m*sizeof(*tmp));
   
-  for (len_t j=0; j<n; j++)
+  for (float_len_t j=0; j<n; j++)
   {
-    for (len_t i=0; i<m; i++)
+    for (float_len_t i=0; i<m; i++)
       tmp[i] += fabsf(x[i + m*j]);
   }
   
-  for (len_t i=0; i<m; i++)
+  for (float_len_t i=0; i<m; i++)
   {
     if (tmp[i] > norm)
       norm = tmp[i];
@@ -52,24 +52,24 @@ static inline float norm_mars(const len_t m, const len_t n, const float *const r
 }
 
 // euclidean norm
-static inline float norm_euc(const len_t m, const len_t n, const float *const restrict x)
+static inline float norm_euc(const float_len_t m, const float_len_t n, const float *const restrict x)
 {
   float scale = 0.0f;
   float sumsq = 1.0f;
-  for (len_t j=0; j<n; j++)
+  for (float_len_t j=0; j<n; j++)
     F77_CALL(slassq)(&m, x + m*j, &(int){1}, &scale, &sumsq);
   
   return scale * sqrtf(sumsq);
 }
 
 // max modulus
-static inline float norm_maxmod(const len_t m, const len_t n, const float *const restrict x)
+static inline float norm_maxmod(const float_len_t m, const float_len_t n, const float *const restrict x)
 {
   float norm = 0.0f;
   
-  for (len_t j=0; j<n; j++)
+  for (float_len_t j=0; j<n; j++)
   {
-    for (len_t i=0; i<m; i++)
+    for (float_len_t i=0; i<m; i++)
     {
       if (x[i + m*j] > norm)
         norm = x[i + m*j];
